# uMap project

uMap lets you create maps with OpenStreetMap layers in a minute and embed them in your site.
*Because we think that the more OSM will be used, the more OSM will be improved.*
Built on top of Django and Leaflet.

- Have a look at [our website](https://umap-project.org) for an introduction
- See [our docs](https://docs.umap-project.org/) for technical information
- Come [chat with us on matrix.org](https://app.element.io/#/room/#umap:matrix.org), or join [the mailing-list](https://lists.openstreetmap.org/listinfo/umap)
